# funcx-common

This package contains common utilities for use across various funcX projects.

For example, constants shared between the funcX service and the funcX SDK are
defined here (and may be re-exported by the SDK).
